import { useChat } from "@ai-sdk/react";
import { createFileRoute } from "@tanstack/react-router";

export const Route = createFileRoute("/chats/$agentName")({
  loader: ({ params }) => params,
  component: Chat,
});

function Chat() {
  const { agentName } = Route.useParams();
  const { messages, input, handleInputChange, handleSubmit, addToolResult } =
    useChat(
      /*{
    api: "http://localhost:8787/api/chat",
  }*/ { api: `/api/chat/${agentName}` }
    );
  return (
    <div className="flex flex-col w-full max-w-md py-24 mx-auto stretch">
      {messages.map((message) => (
        <div key={message.id} className="whitespace-pre-wrap">
          <span className="py-1 px-2 bg-gray-200 rounded-4">
            {message.role === "user" ? "User: " : "AI: "}
          </span>
          {message.parts.map((part, i) => {
            switch (part.type) {
              case "text":
                return <span key={`${message.id}-${i}`}>{part.text}</span>;
              case "tool-invocation":
                return (
                  <div key={`${message.id}-${i}`}>
                    <pre>{JSON.stringify(part.toolInvocation, null, 2)}</pre>
                    {part.toolInvocation.state === "call" ? (
                      <div className="flex gap-2">
                        <span>Continue?</span>
                        <button
                          onClick={() => {
                            addToolResult({
                              toolCallId: part.toolInvocation.toolCallId,
                              result: "yes",
                            });
                          }}
                        >
                          Yes
                        </button>
                        <button
                          onClick={() => {
                            addToolResult({
                              toolCallId: part.toolInvocation.toolCallId,
                              result: "no",
                            });
                          }}
                        >
                          No
                        </button>
                      </div>
                    ) : null}
                  </div>
                );
              case "reasoning":
                return (
                  <span key={`${message.id}-${i}`}>
                    (Reasoning) {part.reasoning}
                  </span>
                );
              case "step-start":
                return (
                  <span key={`${message.id}-${i}`}>
                    (Step Start) {JSON.stringify(part)}
                  </span>
                );
              case "source":
                return (
                  <span key={`${message.id}-${i}`}>
                    (Source) {JSON.stringify(part.source)}
                  </span>
                );
              case "file":
                return (
                  <div key={`${message.id}-${i}`}>
                    <span>(File)</span>
                    <a href={part.data}>{part.mimeType}</a>
                  </div>
                );
              default:
                return (
                  <span key={`${message.id}-${i}`}>
                    (?) {JSON.stringify(part)}
                  </span>
                );
            }
          })}
        </div>
      ))}

      <form onSubmit={handleSubmit}>
        <input
          className="fixed dark:bg-zinc-900 bottom-0 w-full max-w-md p-2 mb-8 border border-zinc-300 dark:border-zinc-800 rounded shadow-xl"
          value={input}
          placeholder="Say something..."
          onChange={handleInputChange}
        />
      </form>
    </div>
  );
}
